******************************
Region mapping for TweakReg
******************************

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. automodule:: drizzlepac.mapreg

.. autofunction:: MapReg
.. autofunction:: map_region_files
.. autofunction:: help
